/// <reference types="react" />
import { ComponentClass, StatelessComponent } from 'react';
import { Reducer } from 'pretur.redux';
import { PageInstance } from './pageInstance';
export interface PageTreeRoot {
    [node: string]: PageFolder | Page<any, any, any>;
}
export interface PageFolder {
    titleKey: string;
    path?: string;
    hidden?: boolean;
    contents: PageTreeRoot;
}
export interface Page<TProps, TState, TReducerBuilderData> {
    titleKey: string;
    path?: string;
    hidden?: boolean;
    persistent?: boolean;
    component: ComponentClass<TProps> | StatelessComponent<TProps>;
    reducerBuilder: PageReducerBuilder<TReducerBuilderData, TState>;
}
export declare function buildPage<TProps, TState, TReducerBuilderData>(component: ComponentClass<TProps> | StatelessComponent<TProps>, reducerBuilder: PageReducerBuilder<TReducerBuilderData, TState>, titleKey: string, dynamic?: boolean): Page<TProps, TState, TReducerBuilderData>;
export interface PageReducerBuilder<T, S> {
    (data?: T): Reducer<S>;
}
export interface PageFolderDescriptor {
    path: string;
    titleKey: string;
    hidden?: boolean;
}
export interface PageDescriptor<TProps, TState, TReducerBuilderData> {
    path: string;
    titleKey: string;
    hidden?: boolean;
    persistent?: boolean;
    component: ComponentClass<TProps> | StatelessComponent<TProps>;
    reducerBuilder: PageReducerBuilder<TReducerBuilderData, TState>;
}
export interface PageInstantiationData<TReducerBuilderData> {
    path: string;
    mutex: string;
    reducerBuilderData?: TReducerBuilderData;
    titleData?: any;
}
export declare type PathTreeNode = string | PathTree;
export interface PathTree extends Array<PathTreeNode> {
}
export interface FolderContents {
    [folder: string]: string[];
}
export declare class Pages {
    private pages;
    private folders;
    private calculatedPathTree;
    private calculatedFolderContents;
    private calculatedFilteredPathTree;
    private calculatedFilteredFolderContents;
    constructor(root: PageTreeRoot);
    hasPage(path: string): boolean;
    getPage(path: string): PageDescriptor<any, any, any>;
    hasFolder(path: string): boolean;
    getFolder(path: string): PageFolderDescriptor;
    isHidden(path: string): boolean;
    readonly pathTree: PathTree;
    readonly folderContents: FolderContents;
    readonly filteredPathTree: PathTree;
    readonly filteredFolderContents: FolderContents;
    buildInstance<TProps, TState, TReducerBuilderData>(instantiationData: PageInstantiationData<TReducerBuilderData>): PageInstance<TProps, TState, TReducerBuilderData>;
}
